package com.simonstl.midp.tam;

/*
 * This interface is placed in the public domain by Simon St.Laurent.
 */
import java.io.InputStream;
/**
 * The API used to set up and start a TAM-based parser. Based loosely on the SAX2
 * XMLReader interface.
 *
 * @author  simonstl
 */
public interface TamParser {
   
   /**
   * Lets you set the handler assigned to a particular parser.
   */
   public void setHandler(TamHandler handler); 
   
   /**
    * Lets you retrieve the handler assigned to a particular parser.
   */
   public TamHandler getHandler();
   
   
   /**
    * Clears entity and namespace state from prior operations.
   */
   public void reset() throws TAMException;
   
   /**
    * Works the same as the SAX2 parse(InputStream in) method.  Because J2ME devices
    * vary widely, there is no support in TAM for parse(String systemID)
    */
   public void parse (InputStream in) throws TAMException;

   /**
    * Works like the SAX2 setFeature() method.  TAM parsers are not required to support
    * any particular features.  setFeature() should generally be used before parsing.
    * SAX2 properties are not supported.
    **/
   public void setFeature(String name, boolean value) throws TAMException;

   /**
    * Works like the SAX2 getFeature() method.  TAM parsers are not required to support
    * any particular features.  getFeature() may be used at any time.
    * SAX2 properties are not supported.
    **/
   public boolean getFeature(String name) throws TAMException;
   
   /**
    * Allows applications to set additional entities for the parser to resolve
    * beyond the built-in set. You cannot override the built-in entities.  To 
    * "undeclare" an entity, set its value to null.
    **/
   public void setEntity(String name, String value) throws TAMException;
   
   /**
    * Sets a namespace which will be used in processing.  This takes effect as
    * if it had been declared in the current level of document processing.  Most
    * typically, applications should set this before the root element is processed
    * and avoid more complex efforts to play with namespaces in particular scopes.
    * Once an element has been reported, it's not like you can go back and replay
    * the reporting event.
    **/
   public void setNamespace(String prefix, String nsURI) throws TAMException;

}

