package com.simonstl.midp.xml;

/*
The contents of this file are subject to the Mozilla Public License  Version 1.1 (the "License"); you may not use this file except in  compliance with the License. You may obtain a copy of the License at 
http://www.mozilla.org/MPL/ 
Software distributed under the License is distributed on an "AS IS"  basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the  License for the specific language governing rights and limitations under  the License. 

The Original Code is available at  http://simonstl.com/projects/fragment/original. 

The Initial Developer of the Original Code is Simon St.Laurent. Portions created by Simon St.Laurent are Copyright (C) 2001. All Rights Reserved. 

Contributor(s): 
*/

import java.io.InputStream;
import com.simonstl.midp.tam.*; 

/**
 *
 * HandlerTest is a very basic extension of {@link com.simonstl.midp.xml.TAMHandlerImpl TAMHandlerImpl}
 * that reports events to System.out.
 *
 * @author  simonstl
 */
public class HandlerTest extends TAMHandlerImpl {
    
    /** Creates a new instance of HandlerTest */
    public HandlerTest() {
       
    }
    
   public void startElement(String uri, String localName, String prefix, TamAttributes attributes) throws TAMException{
       StringBuffer contents=new StringBuffer("Start: |"+ prefix+":"+localName+" ("+uri+")|");
       int count=attributes.getLength();
       
       for (int i=0; i<count; i++){
           String attPrefix=attributes.getPrefix(i);
           contents.append(attPrefix);
           contents.append(":");
           String name=attributes.getLocalName(i);
           contents.append(name);
           contents.append("--");
           String attUri=attributes.getUri(i);
           contents.append(attUri);
           contents.append("--='");
           String value=attributes.getValue(i);
           contents.append(value);
           contents.append("' ");
       }
       
       System.out.println(contents);
   }
   
   public void endElement(String uri, String localName, String prefix) throws TAMException{
       System.out.println("End: |"+ prefix+":"+localName+" ("+uri+")|");
   }
   
   public void characters(char buf[], int offset, int length) throws TAMException{
       System.out.println("Chars: "+ new String(buf));
   }
   
   public void comment(char buf[], int offset, int length) throws TAMException{
       System.out.println("<!--"+ new String(buf)+"-->");
   }
   
   public void doctype(char buf[], int offset, int length) throws TAMException{
       System.out.println("<!"+ new String(buf)+">");
   }
   
   public void XMLDecl(String version, String encoding, String standalone){
       System.out.println("<?xml version=\"" + version +
                            "\" encoding=\"" + encoding +
                            "\" standalone=\"" + standalone + "\"?>");
   }
   
   public void processingInstruction(String target, String data){
       System.out.println("PI: <?"+target+" "+data+"?>");
   }
   
   public void fatalError(TAMException e) {
       System.out.println(e);
       System.exit(0);
   }
    
    public void test() throws TAMException {
        TAMParserImpl parser=new TAMParserImpl();
        //parser.reset();
        parser.setHandler(this);
        parser.setEntity("hook", "curveball");
        parser.setNamespace("bo", "http://simonstl.com");
        parser.setNamespace("", "http://simonstl.com/default");
        InputStream is=getClass().getResourceAsStream("test.xml");
        try {parser.parse(is);} 
        catch (TAMException e) {
            System.out.println("BLAM!");
        }
        
    }
    
    public static void main(String[] args) throws Exception{
        HandlerTest test=new HandlerTest();
        
        test.test();
        
        
 
    }
}
